==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Kết thúc màn chơi hiện tại?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Tạm dừng&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click để chơi tiếp.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Chết queo rồi !&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click để bắt đầu màn chơi mới.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Chọn ngôn ngữ hiển thị:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Ngôn ngữ theo hệ thống&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Ghi chú</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Xin vui lòng khởi động lại ứng dụng này để thao tác thay đổi ngôn ngữ có hiệu lực.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Điểm trên Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Cấp độ</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Dòng</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Điểm</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Đồng Ý</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Click để bắt đầu màn chơi mới.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Màn chơi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Tạo mới</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Tạm dừng</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Chơi tiếp</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Điểm số</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Thoát</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Thiết lập</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ngôn ngữ &amp;hiển thị..</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Trợ giúp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Dịch bởi Vietnamesel10n</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Thông tin về &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Miếng tiếp theo</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Cấp độ</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Các dòng đã gỡ bỏ</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Điểm</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Đây là phiên bản game xếp hình mà tôi dành tặng cho vợ mình</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Phát hành dựa theo giấy phép &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Kết thúc màn chơi hiện tại?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Tạm dừng&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click để chơi tiếp.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Chết queo rồi !&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click để bắt đầu màn chơi mới.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Chọn ngôn ngữ hiển thị:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Ngôn ngữ theo hệ thống&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Ghi chú</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Xin vui lòng khởi động lại ứng dụng này để thao tác thay đổi ngôn ngữ có hiệu lực.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Cấp độ</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Dòng</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Điểm</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Click để bắt đầu màn chơi mới.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Màn chơi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Tạo mới</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Tạm dừng</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Điểm số</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Thoát</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Thiết lập</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ngôn ngữ &amp;hiển thị..</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Trợ giúp</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Dịch bởi Vietnamesel10n</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Thông tin về &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Miếng tiếp theo</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Cấp độ</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Các dòng đã gỡ bỏ</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Điểm</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Phát hành dựa theo giấy phép &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
